@@ -1,5 +1,6 @@
 from pythautomata.base_types.sequence import Sequence
-from pythautomata.automata.wheighted_automaton_definition.probabilistic_deterministic_finite_automaton import ProbabilisticDeterministicFiniteAutomaton as PDFA
+from pythautomata.automata.wheighted_automaton_definition.probabilistic_deterministic_finite_automaton import \
+     ProbabilisticDeterministicFiniteAutomaton as PDFA
 from pythautomata.abstract.finite_automaton import FiniteAutomataComparator
 from pymodelextractor.teachers.probabilistic_teacher import ProbabilisticTeacher
 from typing import Union
@@ -18,7 +19,7 @@ class PDFATeacher(ProbabilisticTeacher):
         return self.__target_pdfa_model.log_sequence_weight(sequence)
 
     def last_token_weights(self, sequence: Sequence, required_suffixes: list[Sequence]):
-        self._last_token_weight_queries_count +=len(required_suffixes)            
+        self._last_token_weight_queries_count += len(required_suffixes)
         return self.__target_pdfa_model.get_last_token_weights(sequence, required_suffixes)
 
     def get_log_probability_error(self, seq, aut: PDFA):
@@ -28,7 +29,7 @@ class PDFATeacher(ProbabilisticTeacher):
         self._equivalence_queries_count += 1
         counterexample = self._comparison_strategy.get_counterexample_between(aut, self.__target_pdfa_model)
         are_equivalent = counterexample is None
-        return (are_equivalent, counterexample)
+        return are_equivalent, counterexample
 
     @property
     def alphabet(self):
